@@ -81,6 +81,24 @@ sequential_duplicated <- function(x, rows=F){
   return(duplicates)
 }
 
+#'Unwraps a matrix and only keep the first n elements.
+#'
+#'A function that unwraps a matrix and only keeps the first n elements
+#' n can be either a constant (in which case it will be repeated), or a vector
+#' @param mat A matrix
+#' @param n A numeric vector
+#' @return A logical vector of the same length as x
+#' @export
+unwrap_rows <- function(mat,n){
+  n <- rep_len(n,nrow(mat))
+  i <- 0
+  out <- lapply(1:nrow(mat),function(i){
+    return(mat[i,1:n[i]])
+  })
+  return(as.numeric(do.call(c,out)))
+}
+
+
 #' Use RCurl to download a file.
 #'
 #' This function makes it easy to implement timestamping and no-clobber of files.
